| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Test.Syd.OptParse
Synopsis
- getSettings :: IO Settings
- data Settings = Settings {
- settingSeed :: !SeedSetting
- settingRandomiseExecutionOrder :: !Bool
- settingThreads :: !Threads
- settingMaxSuccess :: !Int
- settingMaxSize :: !Int
- settingMaxDiscard :: !Int
- settingMaxShrinks :: !Int
- settingGoldenStart :: !Bool
- settingGoldenReset :: !Bool
- settingTerminalCapabilities :: !TerminalCapabilities
- settingFilters :: ![Text]
- settingFailFast :: !Bool
- settingIterations :: !Iterations
- settingTimeout :: !Timeout
- settingRetries :: !Word
- settingFailOnFlaky :: !Bool
- settingSkipPassed :: !Bool
- settingReportFile :: !(Maybe (Path Abs File))
- settingReportProgress :: !ReportProgress
- settingProfile :: !Bool
- settingOutputFormat :: !OutputFormat
- data OutputFormat
- defaultSettings :: Settings
- defaultTimeout :: Int
- defaultRetries :: Word
- detectTerminalCapabilities :: IO TerminalCapabilities
- data Flags = Flags {
- flagSeed :: !SeedSetting
- flagRandomiseExecutionOrder :: !(Maybe Bool)
- flagThreads :: !(Maybe Threads)
- flagMaxSize :: !Int
- flagMaxSuccess :: !Int
- flagMaxDiscard :: !Int
- flagMaxShrinks :: !Int
- flagGoldenStart :: !Bool
- flagGoldenReset :: !Bool
- flagColour :: !(Maybe Bool)
- flagFilters :: ![Text]
- flagFailFast :: !(Maybe Bool)
- flagIterations :: !Iterations
- flagRetries :: !(Maybe Word)
- flagTimeout :: !Timeout
- flagFailOnFlaky :: !Bool
- flagSkipPassed :: !Bool
- flagReportFile :: !(Maybe (Path Abs File))
- flagReportProgress :: !(Maybe ReportProgress)
- flagDebug :: !Bool
- flagProfile :: !Bool
- flagAiExecutor :: !(Maybe Bool)
- flagOutputFormat :: !(Maybe OutputFormat)
- data Timeout
- data Threads
- data Iterations
- data ReportProgress
Documentation
getSettings :: IO Settings Source #
Test suite definition and run settings
Constructors
| Settings | |
Fields
| |
Instances
data OutputFormat Source #
Output format for test results
Constructors
| OutputFormatPretty | Pretty output with colors, unicode symbols, and detailed formatting |
| OutputFormatTerse | Terse output optimized for machine/AI consumption |
Instances
| HasCodec OutputFormat Source # | |||||
Defined in Test.Syd.OptParse Methods codec :: JSONCodec OutputFormat # listCodecForStringCompatibility :: JSONCodec [OutputFormat] # | |||||
| Bounded OutputFormat Source # | |||||
Defined in Test.Syd.OptParse | |||||
| Enum OutputFormat Source # | |||||
Defined in Test.Syd.OptParse Methods succ :: OutputFormat -> OutputFormat # pred :: OutputFormat -> OutputFormat # toEnum :: Int -> OutputFormat # fromEnum :: OutputFormat -> Int # enumFrom :: OutputFormat -> [OutputFormat] # enumFromThen :: OutputFormat -> OutputFormat -> [OutputFormat] # enumFromTo :: OutputFormat -> OutputFormat -> [OutputFormat] # enumFromThenTo :: OutputFormat -> OutputFormat -> OutputFormat -> [OutputFormat] # | |||||
| Generic OutputFormat Source # | |||||
Defined in Test.Syd.OptParse Associated Types
| |||||
| Show OutputFormat Source # | |||||
Defined in Test.Syd.OptParse Methods showsPrec :: Int -> OutputFormat -> ShowS # show :: OutputFormat -> String # showList :: [OutputFormat] -> ShowS # | |||||
| Eq OutputFormat Source # | |||||
Defined in Test.Syd.OptParse | |||||
| type Rep OutputFormat Source # | |||||
Defined in Test.Syd.OptParse | |||||
defaultTimeout :: Int Source #
Constructors
| Flags | |
Fields
| |
Instances
| Generic Flags Source # | |||||
Defined in Test.Syd.OptParse Associated Types
| |||||
| Show Flags Source # | |||||
| Eq Flags Source # | |||||
| HasParser Flags Source # | |||||
Defined in Test.Syd.OptParse Methods | |||||
| type Rep Flags Source # | |||||
Defined in Test.Syd.OptParse type Rep Flags = D1 ('MetaData "Flags" "Test.Syd.OptParse" "sydtest-0.23.0.1-F78Bj4ZIZPQJ2AO9FIYceo" 'False) (C1 ('MetaCons "Flags" 'PrefixI 'True) ((((S1 ('MetaSel ('Just "flagSeed") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 SeedSetting) :*: S1 ('MetaSel ('Just "flagRandomiseExecutionOrder") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Bool))) :*: (S1 ('MetaSel ('Just "flagThreads") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Threads)) :*: (S1 ('MetaSel ('Just "flagMaxSize") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int) :*: S1 ('MetaSel ('Just "flagMaxSuccess") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int)))) :*: ((S1 ('MetaSel ('Just "flagMaxDiscard") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int) :*: (S1 ('MetaSel ('Just "flagMaxShrinks") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int) :*: S1 ('MetaSel ('Just "flagGoldenStart") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool))) :*: (S1 ('MetaSel ('Just "flagGoldenReset") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool) :*: (S1 ('MetaSel ('Just "flagColour") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Bool)) :*: S1 ('MetaSel ('Just "flagFilters") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 [Text]))))) :*: (((S1 ('MetaSel ('Just "flagFailFast") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Bool)) :*: (S1 ('MetaSel ('Just "flagIterations") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Iterations) :*: S1 ('MetaSel ('Just "flagRetries") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Word)))) :*: (S1 ('MetaSel ('Just "flagTimeout") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Timeout) :*: (S1 ('MetaSel ('Just "flagFailOnFlaky") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool) :*: S1 ('MetaSel ('Just "flagSkipPassed") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool)))) :*: ((S1 ('MetaSel ('Just "flagReportFile") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe (Path Abs File))) :*: (S1 ('MetaSel ('Just "flagReportProgress") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe ReportProgress)) :*: S1 ('MetaSel ('Just "flagDebug") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool))) :*: (S1 ('MetaSel ('Just "flagProfile") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Bool) :*: (S1 ('MetaSel ('Just "flagAiExecutor") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe Bool)) :*: S1 ('MetaSel ('Just "flagOutputFormat") 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 (Maybe OutputFormat)))))))) | |||||
Constructors
| DoNotTimeout | |
| TimeoutAfterMicros !Int |
Instances
| HasCodec Timeout Source # | |||||
Defined in Test.Syd.OptParse | |||||
| Generic Timeout Source # | |||||
Defined in Test.Syd.OptParse Associated Types
| |||||
| Read Timeout Source # | |||||
| Show Timeout Source # | |||||
| Eq Timeout Source # | |||||
| HasParser Timeout Source # | |||||
Defined in Test.Syd.OptParse Methods | |||||
| type Rep Timeout Source # | |||||
Defined in Test.Syd.OptParse type Rep Timeout = D1 ('MetaData "Timeout" "Test.Syd.OptParse" "sydtest-0.23.0.1-F78Bj4ZIZPQJ2AO9FIYceo" 'False) (C1 ('MetaCons "DoNotTimeout" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "TimeoutAfterMicros" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Int))) | |||||
Constructors
| Synchronous | One thread |
| ByCapabilities | As many threads as |
| Asynchronous !Word | A given number of threads |
Instances
| HasCodec Threads Source # | |||||
Defined in Test.Syd.OptParse | |||||
| Generic Threads Source # | |||||
Defined in Test.Syd.OptParse Associated Types
| |||||
| Read Threads Source # | |||||
| Show Threads Source # | |||||
| Eq Threads Source # | |||||
| HasParser Threads Source # | |||||
Defined in Test.Syd.OptParse Methods | |||||
| type Rep Threads Source # | |||||
Defined in Test.Syd.OptParse type Rep Threads = D1 ('MetaData "Threads" "Test.Syd.OptParse" "sydtest-0.23.0.1-F78Bj4ZIZPQJ2AO9FIYceo" 'False) (C1 ('MetaCons "Synchronous" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "ByCapabilities" 'PrefixI 'False) (U1 :: Type -> Type) :+: C1 ('MetaCons "Asynchronous" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word)))) | |||||
data Iterations Source #
Constructors
| OneIteration | Run the test suite once, the default |
| Iterations !Word | Run the test suite for the given number of iterations, or until we can find flakiness |
| Continuous | Run the test suite over and over, until we can find some flakiness |
Instances
| HasCodec Iterations Source # | |||||
Defined in Test.Syd.OptParse | |||||
| Generic Iterations Source # | |||||
Defined in Test.Syd.OptParse Associated Types
| |||||
| Read Iterations Source # | |||||
Defined in Test.Syd.OptParse Methods readsPrec :: Int -> ReadS Iterations # readList :: ReadS [Iterations] # readPrec :: ReadPrec Iterations # readListPrec :: ReadPrec [Iterations] # | |||||
| Show Iterations Source # | |||||
Defined in Test.Syd.OptParse Methods showsPrec :: Int -> Iterations -> ShowS # show :: Iterations -> String # showList :: [Iterations] -> ShowS # | |||||
| Eq Iterations Source # | |||||
Defined in Test.Syd.OptParse | |||||
| HasParser Iterations Source # | |||||
Defined in Test.Syd.OptParse Methods | |||||
| type Rep Iterations Source # | |||||
Defined in Test.Syd.OptParse type Rep Iterations = D1 ('MetaData "Iterations" "Test.Syd.OptParse" "sydtest-0.23.0.1-F78Bj4ZIZPQJ2AO9FIYceo" 'False) (C1 ('MetaCons "OneIteration" 'PrefixI 'False) (U1 :: Type -> Type) :+: (C1 ('MetaCons "Iterations" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'SourceStrict 'DecidedStrict) (Rec0 Word)) :+: C1 ('MetaCons "Continuous" 'PrefixI 'False) (U1 :: Type -> Type))) | |||||
data ReportProgress Source #
Constructors
| ReportNoProgress | Don't report any progress, the default |
| ReportProgress | Report progress |
Instances
| Generic ReportProgress Source # | |||||
Defined in Test.Syd.OptParse Associated Types
Methods from :: ReportProgress -> Rep ReportProgress x # to :: Rep ReportProgress x -> ReportProgress # | |||||
| Read ReportProgress Source # | |||||
Defined in Test.Syd.OptParse Methods readsPrec :: Int -> ReadS ReportProgress # readList :: ReadS [ReportProgress] # | |||||
| Show ReportProgress Source # | |||||
Defined in Test.Syd.OptParse Methods showsPrec :: Int -> ReportProgress -> ShowS # show :: ReportProgress -> String # showList :: [ReportProgress] -> ShowS # | |||||
| Eq ReportProgress Source # | |||||
Defined in Test.Syd.OptParse Methods (==) :: ReportProgress -> ReportProgress -> Bool # (/=) :: ReportProgress -> ReportProgress -> Bool # | |||||
| HasParser ReportProgress Source # | |||||
Defined in Test.Syd.OptParse Methods | |||||
| type Rep ReportProgress Source # | |||||
Defined in Test.Syd.OptParse | |||||