| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Test.Syd.Output.Common
Synopsis
- padding :: Chunk
- paddingSize :: Int
- orange :: Colour
- darkRed :: Colour
- statusColour :: TestStatus -> Colour
- statusCheckMark :: TestStatus -> Text
- timeChunkFor :: Word64 -> Chunk
- stringChunks :: String -> [[Chunk]]
- indexed :: [a] -> (Word -> a -> b) -> [b]
- commaList :: [String] -> String
- mContextChunks :: Maybe String -> [[Chunk]]
- outputSomeException :: SomeException -> [[Chunk]]
- outputAssertion :: Assertion -> [[Chunk]]
- splitChunksIntoLines :: [Chunk] -> [[Chunk]]
- outputEqualityAssertionFailed :: String -> String -> Maybe [PolyDiff Text Text] -> [[Chunk]]
- formatDiff :: String -> String -> [PolyDiff Text Text] -> [[Chunk]]
- outputNotEqualAssertionFailed :: String -> String -> [[Chunk]]
- outputPredicateSuccessAssertionFailed :: String -> Maybe String -> [[Chunk]]
- outputPredicateFailAssertionFailed :: String -> Maybe String -> [[Chunk]]
- resultForestWidth :: SpecForest a -> Int
- specForestWidth :: forall (a :: [Type]) b c. SpecDefForest a b c -> Int
Documentation
paddingSize :: Int Source #
statusColour :: TestStatus -> Colour Source #
statusCheckMark :: TestStatus -> Text Source #
timeChunkFor :: Word64 -> Chunk Source #
stringChunks :: String -> [[Chunk]] Source #
outputSomeException :: SomeException -> [[Chunk]] Source #
outputAssertion :: Assertion -> [[Chunk]] Source #
splitChunksIntoLines :: [Chunk] -> [[Chunk]] Source #
Split a list of Chunks into lines of [Chunks].
This is rather complicated because chunks may contain newlines, in which case they need to be split into two chunks on separate lines but with the same colour information. However, separate chunks are not necessarily on separate lines because there may not be a newline inbetween.
outputEqualityAssertionFailed :: String -> String -> Maybe [PolyDiff Text Text] -> [[Chunk]] Source #
resultForestWidth :: SpecForest a -> Int Source #
specForestWidth :: forall (a :: [Type]) b c. SpecDefForest a b c -> Int Source #